
From: David Gibson <david@gibson.dropbear.id.au>

This patch adds a debugging message to the ppc64 hugepage code when we
attempt to open the "low" (32-bit) hugepage window on PPC64, but can't
because a (non-hugepage) mapping already exists in the region.


---

 25-akpm/arch/ppc64/mm/hugetlbpage.c |    5 ++++-
 1 files changed, 4 insertions(+), 1 deletion(-)

diff -puN arch/ppc64/mm/hugetlbpage.c~ppc64-hugepage-useful-warning arch/ppc64/mm/hugetlbpage.c
--- 25/arch/ppc64/mm/hugetlbpage.c~ppc64-hugepage-useful-warning	2004-03-31 22:55:56.308004096 -0800
+++ 25-akpm/arch/ppc64/mm/hugetlbpage.c	2004-03-31 22:55:56.312003488 -0800
@@ -253,8 +253,11 @@ static int open_32bit_htlbpage_range(str
 	/* Check no VMAs are in the region */
 	vma = find_vma(mm, TASK_HPAGE_BASE_32);
 
-	if (vma && (vma->vm_start < TASK_HPAGE_END_32))
+	if (vma && (vma->vm_start < TASK_HPAGE_END_32)) {
+		printk(KERN_DEBUG "Low HTLB region busy: PID=%d  vma @ %lx-%lx\n",
+		       current->pid, vma->vm_start, vma->vm_end);
 		return -EBUSY;
+	}
 
 	/* Clean up any leftover PTE pages in the region */
 	spin_lock(&mm->page_table_lock);

_
